@@ -1,6 +1,6 @@
 # wrapper for calling moveHMM::fitHMM when appropriate models are specified
 #' @importFrom moveHMM fitHMM
-moveHMMwrap<-function(data,nbStates,dist,Par,beta0,delta0,estAngleMean,formula,stationary,nlmPar,fit,nbAnimals){
+moveHMMwrap<-function(data,nbStates,dist,Par,beta0,delta0,estAngleMean,formula,stationary,nlmPar,fit,nbAnimals,knownStates){
   data <- moveData(data)
   distnames<-names(dist)
   
@@ -13,7 +13,7 @@ moveHMMwrap<-function(data,nbStates,dist,Par,beta0,delta0,estAngleMean,formula,s
     if(!is.null(estAngleMean$angle)) 
       if(estAngleMean$angle) angleMean<-NULL
       
-    out<-moveHMM::fitHMM(data,nbStates,Par$step,Par$angle,beta0,delta0,formula,dist$step,dist$angle,angleMean,stationary,knownStates=NULL,verbose,nlmPar,fit)
+    out<-moveHMM::fitHMM(data,nbStates,Par$step,Par$angle,beta0,delta0,formula,dist$step,dist$angle,angleMean,stationary,knownStates,verbose,nlmPar,fit)
     estAngleMean<-list(step=FALSE,angle=out$conditions$estAngleMean)
     zeroInflation<-list(step=out$conditions$zeroInflation,angle=FALSE)
     cons<-list(step=rep(1,length(Par$step)),angle=rep(1,length(Par$angle)))
@@ -21,7 +21,7 @@ moveHMMwrap<-function(data,nbStates,dist,Par,beta0,delta0,estAngleMean,formula,s
     mle<-out$mle
     mle$angle<-matrix(c(t(mle$anglePar)),length(mle$anglePar),1)
   } else {
-    out<-moveHMM::fitHMM(data,nbStates,Par$step,Par$angle,beta0,delta0,formula,dist$step,"none",NULL,stationary,knownStates=NULL,verbose,nlmPar,fit)
+    out<-moveHMM::fitHMM(data,nbStates,Par$step,Par$angle,beta0,delta0,formula,dist$step,"none",NULL,stationary,knownStates,verbose,nlmPar,fit)
     estAngleMean<-list(step=FALSE)
     zeroInflation<-list(step=out$conditions$zeroInflation)
     cons<-list(step=rep(1,length(Par$step)))
